"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const uf = __importStar(require("./utils"));
exports.euclidean = (v1, v2) => {
    return Math.sqrt(v1.map((el, i) => {
        return Math.pow(el - v2[i], 2);
    })
        .reduce(uf.psum, 0));
};
exports.manhattan = (v1, v2) => {
    return v1.map((el, i) => {
        return Math.abs(el - v2[i]);
    }).reduce(uf.psum);
};
exports.braycurtis = (v1, v2) => {
    const n = v1.map((el, i) => { return Math.abs(el - v2[i]); })
        .reduce(uf.psum);
    const d = uf.asum(v1) + uf.asum(v2);
    return n / d;
};
exports.chebyshev = (v1, v2) => {
    return v1.map((el, i) => { return Math.abs(el - v2[i]); })
        .reduce(uf.pmax);
};
exports.canberra = (v1, v2) => {
    return v1.reduce(function (acc, el, i) {
        const n = Math.abs(el - v2[i]);
        const d = Math.abs(el) + Math.abs(v2[i]);
        if (d !== 0) {
            acc.push(n / d);
        }
        return acc;
    }, [])
        .reduce(uf.psum);
};
exports.hamming = (v1, v2) => {
    var cnts = v1.reduce(function (acc, el, i) {
        let si = el !== v2[i] ? 1 : 0;
        acc.s += si;
        acc.t += 1;
        return acc;
    }, { s: 0, t: 0 });
    return cnts.s / cnts.t;
};
